import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/barcode_parsers/barcode_scanner.dart';

part 'disability_certificate.g.dart';

/// Disability certificate parsed barcode document
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DisabilityCertificateDocument extends BarcodeFormattedResult {
  static const String DOCUMENT_FORMAT = 'DisabilityCertificate';

  /// Fields in parsed document
  List<DisabilityCertificateDocumentField> fields;

  DisabilityCertificateDocument(this.fields) : super(DOCUMENT_FORMAT);

  factory DisabilityCertificateDocument.fromJson(Map<String, dynamic> json) =>
      _$DisabilityCertificateDocumentFromJson(json);

  @override
  Map<String, dynamic> toJson() => _$DisabilityCertificateDocumentToJson(this);
}

/// Disability certificate document field
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DisabilityCertificateDocumentField {
  /// Field type
  DisabilityCertificateDocumentFieldType type;

  /// Field value
  String value;

  DisabilityCertificateDocumentField(this.type, this.value);

  factory DisabilityCertificateDocumentField.fromJson(
          Map<String, dynamic> json) =>
      _$DisabilityCertificateDocumentFieldFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DisabilityCertificateDocumentFieldToJson(this);
}

/// DC document field types
enum DisabilityCertificateDocumentFieldType {
  RequiresCare,
  Accident,
  InitialCertificate,
  RenewedCertificate,
  WorkAccident,
  AssignedToAccidentInsuranceDoctor,
  IncapableOfWorkSince,
  IncapableOfWorkUntil,
  DiagnosedOn,
  DocumentDate,
  BirthDate,
  FirstName,
  LastName,
  Diagnose,
  HealthInsuranceNumber,
  InsuredPersonNumber,
  Status,
  PlaceOfOperationNumber,
  DoctorNumber,
  ChildNeedsCareFrom,
  ChildNeedsCareUntil
}
